from . import processing

def detect_ellipsoids(data_container_array, feature_ids_array_path = None, detected_ellipsoids_feature_ids_array_path = None, feature_attribute_matrix_path = None, ellipse_feature_attribute_matrix_path = None, center_coordinates_array_name = None, major_axis_length_array_name = None, minor_axis_length_array_name = None, rotational_angles_array_name = None, min_fiber_axis_length = None, max_fiber_axis_length = None, hough_transform_threshold = None, min_aspect_ratio = None, image_scale_bar_length = None, observer = None) -> int:
  """Pythonic interface to DetectEllipsoids Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    feature_ids_array_path (DataArrayPath): Sets the "FeatureIdsArrayPath" filter property
    detected_ellipsoids_feature_ids_array_path (DataArrayPath): Sets the "DetectedEllipsoidsFeatureIdsArrayPath" filter property
    feature_attribute_matrix_path (DataArrayPath): Sets the "FeatureAttributeMatrixPath" filter property
    ellipse_feature_attribute_matrix_path (DataArrayPath): Sets the "EllipseFeatureAttributeMatrixPath" filter property
    center_coordinates_array_name (QString): Sets the "CenterCoordinatesArrayName" filter property
    major_axis_length_array_name (QString): Sets the "MajorAxisLengthArrayName" filter property
    minor_axis_length_array_name (QString): Sets the "MinorAxisLengthArrayName" filter property
    rotational_angles_array_name (QString): Sets the "RotationalAnglesArrayName" filter property
    min_fiber_axis_length (int): Sets the "MinFiberAxisLength" filter property
    max_fiber_axis_length (int): Sets the "MaxFiberAxisLength" filter property
    hough_transform_threshold (float): Sets the "HoughTransformThreshold" filter property
    min_aspect_ratio (float): Sets the "MinAspectRatio" filter property
    image_scale_bar_length (int): Sets the "ImageScaleBarLength" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = processing.DetectEllipsoids()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if feature_ids_array_path is not None:
    filter.FeatureIdsArrayPath = feature_ids_array_path
  if detected_ellipsoids_feature_ids_array_path is not None:
    filter.DetectedEllipsoidsFeatureIdsArrayPath = detected_ellipsoids_feature_ids_array_path
  if feature_attribute_matrix_path is not None:
    filter.FeatureAttributeMatrixPath = feature_attribute_matrix_path
  if ellipse_feature_attribute_matrix_path is not None:
    filter.EllipseFeatureAttributeMatrixPath = ellipse_feature_attribute_matrix_path
  if center_coordinates_array_name is not None:
    filter.CenterCoordinatesArrayName = center_coordinates_array_name
  if major_axis_length_array_name is not None:
    filter.MajorAxisLengthArrayName = major_axis_length_array_name
  if minor_axis_length_array_name is not None:
    filter.MinorAxisLengthArrayName = minor_axis_length_array_name
  if rotational_angles_array_name is not None:
    filter.RotationalAnglesArrayName = rotational_angles_array_name
  if min_fiber_axis_length is not None:
    filter.MinFiberAxisLength = min_fiber_axis_length
  if max_fiber_axis_length is not None:
    filter.MaxFiberAxisLength = max_fiber_axis_length
  if hough_transform_threshold is not None:
    filter.HoughTransformThreshold = hough_transform_threshold
  if min_aspect_ratio is not None:
    filter.MinAspectRatio = min_aspect_ratio
  if image_scale_bar_length is not None:
    filter.ImageScaleBarLength = image_scale_bar_length
  filter.execute()
  return filter.ErrorCode

def erode_dilate_bad_data(data_container_array, direction = None, num_iterations = None, x_dir_on = None, y_dir_on = None, z_dir_on = None, feature_ids_array_path = None, observer = None) -> int:
  """Pythonic interface to ErodeDilateBadData Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    direction (Uint): Sets the "Direction" filter property
    num_iterations (int): Sets the "NumIterations" filter property
    x_dir_on (bool): Sets the "XDirOn" filter property
    y_dir_on (bool): Sets the "YDirOn" filter property
    z_dir_on (bool): Sets the "ZDirOn" filter property
    feature_ids_array_path (DataArrayPath): Sets the "FeatureIdsArrayPath" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = processing.ErodeDilateBadData()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if direction is not None:
    filter.Direction = direction
  if num_iterations is not None:
    filter.NumIterations = num_iterations
  if x_dir_on is not None:
    filter.XDirOn = x_dir_on
  if y_dir_on is not None:
    filter.YDirOn = y_dir_on
  if z_dir_on is not None:
    filter.ZDirOn = z_dir_on
  if feature_ids_array_path is not None:
    filter.FeatureIdsArrayPath = feature_ids_array_path
  filter.execute()
  return filter.ErrorCode

def erode_dilate_coordination_number(data_container_array, loop = None, coordination_number = None, feature_ids_array_path = None, observer = None) -> int:
  """Pythonic interface to ErodeDilateCoordinationNumber Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    loop (bool): Sets the "Loop" filter property
    coordination_number (int): Sets the "CoordinationNumber" filter property
    feature_ids_array_path (DataArrayPath): Sets the "FeatureIdsArrayPath" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = processing.ErodeDilateCoordinationNumber()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if loop is not None:
    filter.Loop = loop
  if coordination_number is not None:
    filter.CoordinationNumber = coordination_number
  if feature_ids_array_path is not None:
    filter.FeatureIdsArrayPath = feature_ids_array_path
  filter.execute()
  return filter.ErrorCode

def erode_dilate_mask(data_container_array, int = None, num_iterations = None, x_dir_on = None, y_dir_on = None, z_dir_on = None, mask_array_path = None, observer = None) -> int:
  """Pythonic interface to ErodeDilateMask Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    int (unsigned): Sets the "int" filter property
    num_iterations (int): Sets the "NumIterations" filter property
    x_dir_on (bool): Sets the "XDirOn" filter property
    y_dir_on (bool): Sets the "YDirOn" filter property
    z_dir_on (bool): Sets the "ZDirOn" filter property
    mask_array_path (DataArrayPath): Sets the "MaskArrayPath" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = processing.ErodeDilateMask()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if int is not None:
    filter.int = int
  if num_iterations is not None:
    filter.NumIterations = num_iterations
  if x_dir_on is not None:
    filter.XDirOn = x_dir_on
  if y_dir_on is not None:
    filter.YDirOn = y_dir_on
  if z_dir_on is not None:
    filter.ZDirOn = z_dir_on
  if mask_array_path is not None:
    filter.MaskArrayPath = mask_array_path
  filter.execute()
  return filter.ErrorCode

def fill_bad_data(data_container_array, store_as_new_phase = None, min_allowed_defect_size = None, feature_ids_array_path = None, cell_phases_array_path = None, observer = None) -> int:
  """Pythonic interface to FillBadData Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    store_as_new_phase (bool): Sets the "StoreAsNewPhase" filter property
    min_allowed_defect_size (int): Sets the "MinAllowedDefectSize" filter property
    feature_ids_array_path (DataArrayPath): Sets the "FeatureIdsArrayPath" filter property
    cell_phases_array_path (DataArrayPath): Sets the "CellPhasesArrayPath" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = processing.FillBadData()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if store_as_new_phase is not None:
    filter.StoreAsNewPhase = store_as_new_phase
  if min_allowed_defect_size is not None:
    filter.MinAllowedDefectSize = min_allowed_defect_size
  if feature_ids_array_path is not None:
    filter.FeatureIdsArrayPath = feature_ids_array_path
  if cell_phases_array_path is not None:
    filter.CellPhasesArrayPath = cell_phases_array_path
  filter.execute()
  return filter.ErrorCode

def find_projected_image_statistics(data_container_array, selected_array_path = None, int = None, projected_image_min_array_name = None, projected_image_max_array_name = None, projected_image_avg_array_name = None, projected_image_std_array_name = None, projected_image_var_array_name = None, observer = None) -> int:
  """Pythonic interface to FindProjectedImageStatistics Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    selected_array_path (DataArrayPath): Sets the "SelectedArrayPath" filter property
    int (unsigned): Sets the "int" filter property
    projected_image_min_array_name (QString): Sets the "ProjectedImageMinArrayName" filter property
    projected_image_max_array_name (QString): Sets the "ProjectedImageMaxArrayName" filter property
    projected_image_avg_array_name (QString): Sets the "ProjectedImageAvgArrayName" filter property
    projected_image_std_array_name (QString): Sets the "ProjectedImageStdArrayName" filter property
    projected_image_var_array_name (QString): Sets the "ProjectedImageVarArrayName" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = processing.FindProjectedImageStatistics()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if selected_array_path is not None:
    filter.SelectedArrayPath = selected_array_path
  if int is not None:
    filter.int = int
  if projected_image_min_array_name is not None:
    filter.ProjectedImageMinArrayName = projected_image_min_array_name
  if projected_image_max_array_name is not None:
    filter.ProjectedImageMaxArrayName = projected_image_max_array_name
  if projected_image_avg_array_name is not None:
    filter.ProjectedImageAvgArrayName = projected_image_avg_array_name
  if projected_image_std_array_name is not None:
    filter.ProjectedImageStdArrayName = projected_image_std_array_name
  if projected_image_var_array_name is not None:
    filter.ProjectedImageVarArrayName = projected_image_var_array_name
  filter.execute()
  return filter.ErrorCode

def find_relative_motion_between_slices(data_container_array, selected_array_path = None, int = None, p_size1 = None, p_size2 = None, s_size1 = None, s_size2 = None, slice_step = None, motion_direction_array_name = None, observer = None) -> int:
  """Pythonic interface to FindRelativeMotionBetweenSlices Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    selected_array_path (DataArrayPath): Sets the "SelectedArrayPath" filter property
    int (unsigned): Sets the "int" filter property
    p_size1 (int): Sets the "PSize1" filter property
    p_size2 (int): Sets the "PSize2" filter property
    s_size1 (int): Sets the "SSize1" filter property
    s_size2 (int): Sets the "SSize2" filter property
    slice_step (int): Sets the "SliceStep" filter property
    motion_direction_array_name (QString): Sets the "MotionDirectionArrayName" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = processing.FindRelativeMotionBetweenSlices()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if selected_array_path is not None:
    filter.SelectedArrayPath = selected_array_path
  if int is not None:
    filter.int = int
  if p_size1 is not None:
    filter.PSize1 = p_size1
  if p_size2 is not None:
    filter.PSize2 = p_size2
  if s_size1 is not None:
    filter.SSize1 = s_size1
  if s_size2 is not None:
    filter.SSize2 = s_size2
  if slice_step is not None:
    filter.SliceStep = slice_step
  if motion_direction_array_name is not None:
    filter.MotionDirectionArrayName = motion_direction_array_name
  filter.execute()
  return filter.ErrorCode

def identify_sample(data_container_array, fill_holes = None, good_voxels_array_path = None, observer = None) -> int:
  """Pythonic interface to IdentifySample Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    fill_holes (bool): Sets the "FillHoles" filter property
    good_voxels_array_path (DataArrayPath): Sets the "GoodVoxelsArrayPath" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = processing.IdentifySample()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if fill_holes is not None:
    filter.FillHoles = fill_holes
  if good_voxels_array_path is not None:
    filter.GoodVoxelsArrayPath = good_voxels_array_path
  filter.execute()
  return filter.ErrorCode

def min_neighbors(data_container_array, min_num_neighbors = None, apply_to_single_phase = None, phase_number = None, feature_ids_array_path = None, feature_phases_array_path = None, num_neighbors_array_path = None, observer = None) -> int:
  """Pythonic interface to MinNeighbors Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    min_num_neighbors (int): Sets the "MinNumNeighbors" filter property
    apply_to_single_phase (bool): Sets the "ApplyToSinglePhase" filter property
    phase_number (int): Sets the "PhaseNumber" filter property
    feature_ids_array_path (DataArrayPath): Sets the "FeatureIdsArrayPath" filter property
    feature_phases_array_path (DataArrayPath): Sets the "FeaturePhasesArrayPath" filter property
    num_neighbors_array_path (DataArrayPath): Sets the "NumNeighborsArrayPath" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = processing.MinNeighbors()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if min_num_neighbors is not None:
    filter.MinNumNeighbors = min_num_neighbors
  if apply_to_single_phase is not None:
    filter.ApplyToSinglePhase = apply_to_single_phase
  if phase_number is not None:
    filter.PhaseNumber = phase_number
  if feature_ids_array_path is not None:
    filter.FeatureIdsArrayPath = feature_ids_array_path
  if feature_phases_array_path is not None:
    filter.FeaturePhasesArrayPath = feature_phases_array_path
  if num_neighbors_array_path is not None:
    filter.NumNeighborsArrayPath = num_neighbors_array_path
  filter.execute()
  return filter.ErrorCode

def min_size(data_container_array, min_allowed_feature_size = None, apply_to_single_phase = None, phase_number = None, feature_ids_array_path = None, feature_phases_array_path = None, num_cells_array_path = None, observer = None) -> int:
  """Pythonic interface to MinSize Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    min_allowed_feature_size (int): Sets the "MinAllowedFeatureSize" filter property
    apply_to_single_phase (bool): Sets the "ApplyToSinglePhase" filter property
    phase_number (int): Sets the "PhaseNumber" filter property
    feature_ids_array_path (DataArrayPath): Sets the "FeatureIdsArrayPath" filter property
    feature_phases_array_path (DataArrayPath): Sets the "FeaturePhasesArrayPath" filter property
    num_cells_array_path (DataArrayPath): Sets the "NumCellsArrayPath" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = processing.MinSize()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if min_allowed_feature_size is not None:
    filter.MinAllowedFeatureSize = min_allowed_feature_size
  if apply_to_single_phase is not None:
    filter.ApplyToSinglePhase = apply_to_single_phase
  if phase_number is not None:
    filter.PhaseNumber = phase_number
  if feature_ids_array_path is not None:
    filter.FeatureIdsArrayPath = feature_ids_array_path
  if feature_phases_array_path is not None:
    filter.FeaturePhasesArrayPath = feature_phases_array_path
  if num_cells_array_path is not None:
    filter.NumCellsArrayPath = num_cells_array_path
  filter.execute()
  return filter.ErrorCode

def remove_flagged_features(data_container_array, fill_removed_features = None, feature_ids_array_path = None, flagged_features_array_path = None, observer = None) -> int:
  """Pythonic interface to RemoveFlaggedFeatures Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    fill_removed_features (bool): Sets the "FillRemovedFeatures" filter property
    feature_ids_array_path (DataArrayPath): Sets the "FeatureIdsArrayPath" filter property
    flagged_features_array_path (DataArrayPath): Sets the "FlaggedFeaturesArrayPath" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = processing.RemoveFlaggedFeatures()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if fill_removed_features is not None:
    filter.FillRemovedFeatures = fill_removed_features
  if feature_ids_array_path is not None:
    filter.FeatureIdsArrayPath = feature_ids_array_path
  if flagged_features_array_path is not None:
    filter.FlaggedFeaturesArrayPath = flagged_features_array_path
  filter.execute()
  return filter.ErrorCode

